# Kuzu WebAssembly Example

This example demonstrates how to use Kuzu WebAssembly in a web browser. In this example, we will create a simple social network database with the following schema:

- Node table `User` with columns `name` and `age`
- Node table `City` with columns `name` and `population`
- Relationship table `Follows` with a relationship from `User` to `User` and a `since` property
- Relationship table `LivesIn` with a relationship from `User` to `City`

We will then load data into these tables and run some queries to demonstrate the capabilities of Kuzu WebAssembly.

In this example, all the queries are evaluated in browser using the WebAssembly version of Kuzu. No server-side processing is involved.

The output of the queries will be displayed below:

``